/*
 * SPDX-License-Identifier: GPL-3.0-only
 * MuseScore-CLA-applies
 *
 * MuseScore
 * Music Composition & Notation
 *
 * Copyright (C) 2023 MuseScore BVBA and others
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef MU_ACCESSIBILITY_ACCESSIBILITYCONTROLLERSTUB_H
#define MU_ACCESSIBILITY_ACCESSIBILITYCONTROLLERSTUB_H

#include "accessibility/iaccessibilitycontroller.h"

namespace muse::accessibility {
class AccessibilityControllerStub : public IAccessibilityController
{
public:
    void reg(IAccessible* item) override;
    void unreg(IAccessible* item) override;

    void announce(const QString& announcement) override;
    QString announcement() const override;

    const IAccessible* accessibleRoot() const override;

    const IAccessible* lastFocused() const override;

    bool needToVoicePanelInfo() const override;
    QString currentPanelAccessibleName() const override;

    void setIgnoreQtAccessibilityEvents(bool ignore) override;
};
}

#endif // MU_ACCESSIBILITY_ACCESSIBILITYCONTROLLERSTUB_H
